/'
 ' Project Publisher - Installer Creator Addin for FbEdit, RadASM and MasmEd
 '
 ' Copyright (C) 2010 Arnel A. Borja (Galeon)
 '
 ' This program is free software: you can redistribute it and/or modify it under 
 ' the terms of the GNU General Public License as published by the Free Software 
 ' Foundation, either version 3 of the License, or (at your option) any later 
 ' version.
 '
 ' This program is distributed in the hope that it will be useful, but WITHOUT 
 ' ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 ' FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more 
 ' details.
 '
 ' You should have received a copy of the GNU General Public License along with 
 ' this program.  If not, see <http://www.gnu.org/licenses/>.
 '
 ' As a special exception, Arnel A. Borja gives unlimited permission to copy, 
 ' distribute and modify the files that are the output of this program, and to 
 ' copy and distribute the resulting files under terms of your choice.  You need 
 ' not follow the terms of the GNU General Public License when using or 
 ' distributing such files, even though portions of the text of the program 
 ' appear in them.  The GNU General Public License (GPL) does govern all other 
 ' use of the material that constitutes the program.
 '
 ' This special exception to the GPL applies to versions of the program released 
 ' by Arnel A. Borja.  When you make and distribute a modified version of the 
 ' program, you may extend this special exception to the GPL to apply to your 
 ' modified version as well.
 '
 '/


#Include Once "windows.bi"
#Include Once "win/commctrl.bi"
#Include Once "win/shellapi.bi"

#Include Once "Inc/FbEdit.bi"
#Include Once "Inc/RadASM2.bi"
#Include Once "Inc/RadASM3.bi"
#Include Once "Inc/MasmEd.bi"

#Include Once "ProjPub.bi"
#Include Once "FileFuncs.bi"
#Include Once "Settings.bi"
#Include Once "Header.bi"
#Include Once "Help.bi"
#Include Once "LangDll.bi"
#Include Once "Resource.bi"


Declare Function GetLanguageId( ByRef Language As Const String ) As Integer
Declare Function GetLanguageIdUsingFilename( ByRef filename As Const String ) As Integer


Function LangDllDialogProc( _
	ByVal hWin As HWND, _
	ByVal uMsg As UINT, _
	ByVal wParam As WPARAM, _
	ByVal lParam As LPARAM _
	) As BOOL

	Select Case uMsg
		Case WM_INITDIALOG
			' Translate dialog box
			TranslateAddinDialog( hWin, IDD_DLGLANGDLL )

			' Add header
			AddHeaderToPage( hWin, _
				GetTranslateString( "4020", "Supported Languages" ), _
				GetTranslateString( "4021", "Choose the languages you want your installer to support." ) _
				)

			' Add languages to list box
			If LanguagesNum Then
				For i As Integer = 0 To LanguagesNum-1
					SendDlgItemMessage( hWin, IDC_LSTLANGDLL, LB_ADDSTRING, 0, Cast( LPARAM, Languages( i ).Name ) )
					Dim CurLanguage As ProjPub_Lang Ptr = (@ProjectSettings.Languages)->Next
					Do While CurLanguage <> NULL
						If UCase( *CurLanguage->Name ) = UCase( *Languages( i ).Name ) Then
							SendDlgItemMessage( hWin, IDC_LSTLANGDLL, LB_SETSEL, TRUE, i )
							Exit Do
						End If
						CurLanguage = CurLanguage->Next
					Loop
				Next
				SendDlgItemMessage( hWin, IDC_LSTLANGDLL, LB_SETCURSEL, Cast( WPARAM, LanguageDefault ), 0 )
			End If

			'
		Case WM_CLOSE
			DestroyWindow(hWin)
			'
		Case WM_NOTIFY
			Select Case Cast( NMHDR Ptr, lParam )->code
				Case PSN_SETACTIVE
					PropSheet_SetWizButtons( Cast( NMHDR Ptr, lParam )->hwndFrom, PSWIZB_BACK Or PSWIZB_NEXT )
					'
				Case PSN_WIZNEXT
					Dim LangCount As Integer = SendDlgItemMessage( hWin, IDC_LSTLANGDLL, LB_GETSELCOUNT, 0, 0 )
					RemoveAllLanguages( @ProjectSettings.Languages )
					If LangCount Then
						Dim LanguageList( 0 To LangCount-1 ) As Integer
						SendDlgItemMessage( hWin, IDC_LSTLANGDLL, LB_GETSELITEMS, LangCount, Cast( LPARAM, @LanguageList(0) ) )
						For i As Integer = 0 To LangCount-1
							SendDlgItemMessage( hWin, IDC_LSTLANGDLL, LB_GETTEXT, LanguageList(i), Cast( LPARAM, @buffer ) )
							InsertLanguageToEnd( @ProjectSettings.Languages, buffer )
						Next
					End If
					'
			End Select
			'
		Case WM_HELP
			ShowContextHelp( Cast( HELPINFO Ptr, lParam ) )
			'
		Case Else
			Return FALSE
			'
	End Select

	Return TRUE

End Function


Sub LoadLanguages( _
	ByRef Location As Const String _
	)

	LanguagesNum = 0
	LanguagesMax = 0

	' Get first file
	Dim fname As String = Dir( Location & "\*.lng" )
	Dim size As Integer

	' Check if fname is valid
	Do While Len( fname )

		' Check FileType
		GetPrivateProfileString( "ProjPub", "FileType", "", @buffer, MAX_PATH, Location + "\" + fname )

		If buffer = "Language" Then

			' Check if the array can accomodate the number of files available
			If LanguagesNum >= LanguagesMax Then
	
				'' There are more files than the array can provide
				LanguagesMax += LANGUAGES_INCREASE
				ReDim Preserve Languages(LanguagesMax - 1) As Language
	
			End If
	
			' Set filename of the current language
			Languages( LanguagesNum ).DescFile = New Byte[Len(Location + "\" + fname)+1]
			*Languages( LanguagesNum ).DescFile = Location + "\" + fname
	
			' Set language info
			size = GetPrivateProfileString( "Language", "Name", "Unnamed", @buffer, MAX_PATH, Location + "\" + fname )
			Languages( LanguagesNum ).Name = New Byte[size+1]
			*Languages( LanguagesNum ).Name = buffer
			size = GetPrivateProfileString( "Language", "Define", "", @buffer, MAX_PATH, Location + "\" + fname )
			Languages( LanguagesNum ).Define = New Byte[size+1]
			*Languages( LanguagesNum ).Define = buffer

			' Check if default is requested
			If GetPrivateProfileInt( "ProjPub", "Default", 0, Location + "\" + fname ) Then
				LanguageDefault = LanguagesNum
			End If
	
			' Increment Languages counter
			LanguagesNum += 1

		End If

		' Get next file name
		fname = Dir( "" )

	Loop

End Sub


Sub FreeLanguages( _
	)

	If LanguagesNum Then
		For i As Integer = 0 To LanguagesNum-1
			Delete[] Languages( i ).Name
			Delete[] Languages( i ).DescFile
			Delete[] Languages( i ).Define
		Next
		LanguagesNum = 0
	End If

End Sub


Function GetLanguageId( _
	ByRef Language As Const String _
	) As Integer

	If LanguagesNum Then
		For i As Integer = 0 To LanguagesNum-1
			If LCase( *Languages(i).Name ) = LCase( Language ) Then
				Return i
			End If
		Next
	End If

	Return -1

End Function


Function GetLanguageIdUsingFilename( _
	ByRef filename As Const String _
	) As Integer

	If LanguagesNum Then
		For i As Integer = 0 To LanguagesNum-1
			If LCase( GetFileName( *Languages(i).DescFile ) ) = LCase( GetFileName( filename ) ) Then
				Return i
			End If
		Next
	End If

	Return -1

End Function


Function GetLanguageDefine( _
	ByRef Language As Const String _
	) As String

	If LanguagesNum Then
		For i As Integer = 0 To LanguagesNum-1
			If LCase( *Languages(i).Name ) = LCase( Language ) Then
				Return *Languages(i).Define
			End If
		Next
	End If

	Return ""

End Function


Function GetLanguageString( _
	ByRef Language As Const String, _
	ByVal StringId As Integer, _
	ByRef Default As Const String _
	) As String

	Dim LanguageId As Integer = GetLanguageId( Language )

	If LanguageId >= 0 And LanguageId < LanguagesNum Then
		GetPrivateProfileString( "Strings", Str( StringId ), "", @buffer, MAX_PATH, Languages(LanguageId).DescFile )
		If buffer <> "" Then Return buffer
	End If

	Return Default

End Function


Sub RemoveLanguage( _
	ByVal Head As ProjPub_Lang Ptr, _
	ByVal id As Integer _
	)

	Dim CurLanguage As ProjPub_Lang Ptr = Head
	Dim PrevLanguage As ProjPub_Lang Ptr

	For i As Integer = 0 To id
		If CurLanguage = NULL Then Return
		PrevLanguage = CurLanguage
		CurLanguage = CurLanguage->Next
	Next

	PrevLanguage->Next=CurLanguage->Next
	Delete[] CurLanguage->Name
	Delete CurLanguage

End Sub


Sub RemoveAllLanguages( _
	ByVal Head As ProjPub_Lang Ptr _
	)

	Dim NextLanguage As ProjPub_Lang Ptr

	Do While Head->Next <> NULL
		NextLanguage=Head->Next->Next
		Delete[] Head->Next->Name
		Delete Head->Next
		Head->Next=NextLanguage
	Loop

End Sub


Function GetLanguagesNum( _
	ByVal Head As ProjPub_Lang Ptr _
	) As Integer

	Dim CurLanguage As ProjPub_Lang Ptr = Head->Next
	Dim Num As Integer

	Do While CurLanguage <> NULL
		CurLanguage = CurLanguage->Next
		Num += 1
	Loop

	Return Num

End Function


Sub InsertLanguageToEnd( _
	ByVal Head As ProjPub_Lang Ptr, _
	ByRef LanguageName As Const String _
	)

	Dim CurLanguage As ProjPub_Lang Ptr = Head

	Do While CurLanguage->Next <> NULL
		CurLanguage = CurLanguage->Next
	Loop

	CurLanguage->Next = New ProjPub_Lang
	CurLanguage->Next->Name = New Byte [Len( LanguageName ) + 1]
	*CurLanguage->Next->Name = LanguageName
	CurLanguage->Next->Next = NULL

End Sub


Sub InsertLanguage( _
	ByVal Head As ProjPub_Lang Ptr, _
	ByVal Id As Integer, _
	ByRef LanguageName As Const String _
	)

	Dim CurLanguage As ProjPub_Lang Ptr = Head
	Dim TempLanguage As ProjPub_Lang Ptr
	Dim CurLanguageId As Integer = 0

	Do Until CurLanguageId = Id
		If CurLanguage->Next <> NULL Then
			CurLanguage = CurLanguage->Next
		Else
			Return
		End If
		CurLanguageId += 1
	Loop

	TempLanguage=CurLanguage->Next
	CurLanguage->Next=New ProjPub_Lang
	CurLanguage->Next->Name = New Byte [Len( LanguageName ) + 1]
	*CurLanguage->Next->Name = LanguageName
	CurLanguage->Next->Next=TempLanguage

End Sub


Sub SetNewLanguageName( _
	ByVal Head As ProjPub_Lang Ptr, _
	ByVal Id As Integer, _
	ByRef LanguageName As Const String _
	)

	Dim CurLanguage As ProjPub_Lang Ptr = Head

	For i As Integer = 0 To id
		If CurLanguage <> NULL Then
			CurLanguage = CurLanguage->Next
		Else
			Return
		End If
	Next

	Delete[] CurLanguage->Name
	CurLanguage->Name=New Byte [Len( LanguageName ) + 1]
	*CurLanguage->Name=LanguageName

End Sub


Function GetLanguage( _
	ByVal Head As ProjPub_Lang Ptr, _
	ByVal Id As Integer _
	) As ProjPub_Lang Ptr

	Dim CurLanguage As ProjPub_Lang Ptr = Head

	For i As Integer = 0 To id
		If CurLanguage <> NULL Then
			CurLanguage = CurLanguage->Next
		Else
			Return NULL
		End If
	Next

	Return CurLanguage

End Function

