/'
 ' ProjPub - Help Addin for FbEdit (FreeBASIC Editor)
 '
 ' Copyright (C) 2010 Arnel A. Borja (Galeon)
 '
 ' This program is free software: you can redistribute it and/or modify it under 
 ' the terms of the GNU General Public License as published by the Free Software 
 ' Foundation, either version 3 of the License, or (at your option) any later 
 ' version.
 '
 ' This program is distributed in the hope that it will be useful, but WITHOUT 
 ' ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS 
 ' FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more 
 ' details.
 '
 ' You should have received a copy of the GNU General Public License along with 
 ' this program.  If not, see <http://www.gnu.org/licenses/>.
 '
 ' As a special exception, Arnel A. Borja gives unlimited permission to copy, 
 ' distribute and modify the files that are the output of this program, and to 
 ' copy and distribute the resulting files under terms of your choice.  You need 
 ' not follow the terms of the GNU General Public License when using or 
 ' distributing such files, even though portions of the text of the program 
 ' appear in them.  The GNU General Public License (GPL) does govern all other 
 ' use of the material that constitutes the program.
 '
 ' This special exception to the GPL applies to versions of the program released 
 ' by Arnel A. Borja.  When you make and distribute a modified version of the 
 ' program, you may extend this special exception to the GPL to apply to your 
 ' modified version as well.
 '
 '/


#Include Once "windows.bi"
#Include Once "win/commctrl.bi"
#Include Once "win/shellapi.bi"

#Include Once "File.bi"

#Include Once "Inc/FbEdit.bi"
#Include Once "Inc/RadASM2.bi"
#Include Once "Inc/RadASM3.bi"
#Include Once "Inc/MasmEd.bi"

#Include Once "ProjPub.bi"
#Include Once "Settings.bi"
#Include Once "FileFuncs.bi"
#Include Once "MsgBox.bi"
#Include Once "Header.bi"
#Include Once "Help.bi"
#Include Once "CustomUI.bi"
#Include Once "Mui.bi"
#Include Once "Resource.bi"


#Define THEMES_INCREASE							3

Type WizardTheme
	Name As ZString Ptr
	DescFile As ZString Ptr
	BitmapInstall As ZString Ptr
	BitmapUninstall As ZString Ptr
End Type

Type HeaderTheme
	Name As ZString Ptr
	DescFile As ZString Ptr
	BitmapInstall As ZString Ptr
	BitmapInstallRight As ZString Ptr
	BitmapUninstall As ZString Ptr
	BitmapUninstallRight As ZString Ptr
End Type

Type IconTheme
	Name As ZString Ptr
	DescFile As ZString Ptr
	IconInstall As ZString Ptr
	IconUninstall As ZString Ptr
End Type

Const NSISGraphicsPath As String = "\Contrib\Graphics\"
Const ProjPubGraphicsPath As String = "\ProjPub\Graphics\"
Const CustomProjPubGraphicsPath As String = "\ProjPub\Graphics\Custom\"

Dim Shared WizardThemes(  ) As WizardTheme
Dim Shared WizardThemesNum As Integer
Dim Shared WizardThemesMax As Integer
Dim Shared WizardThemeDefault As Integer

Dim Shared HeaderThemes(  ) As HeaderTheme
Dim Shared HeaderThemesNum As Integer
Dim Shared HeaderThemesMax As Integer
Dim Shared HeaderThemeDefault As Integer

Dim Shared IconThemes(  ) As IconTheme
Dim Shared IconThemesNum As Integer
Dim Shared IconThemesMax As Integer
Dim Shared IconThemeDefault As Integer

Declare Sub AddToWizardThemes( ByVal Filename As String )
Declare Sub AddToHeaderThemes( ByVal Filename As String )
Declare Sub AddToIconThemes( ByVal Filename As String )
Declare Function GetWizardThemeId( ByRef filename As Const String ) As Integer
Declare Function GetHeaderThemeId( ByRef filename As Const String ) As Integer
Declare Function GetIconThemeId( ByRef filename As Const String ) As Integer
Declare Function GetWizardFilePath( ByRef filename As Const String ) As String
Declare Function GetHeaderFilePath( ByRef filename As Const String ) As String
Declare Function GetIconFilePath( ByRef filename As Const String ) As String


Function MuiDialogProc( _
	ByVal hWin As HWND, _
	ByVal uMsg As UINT, _
	ByVal wParam As WPARAM, _
	ByVal lParam As LPARAM _
	) As BOOL

	Select Case uMsg
		Case WM_INITDIALOG
			' Translate dialog box
			TranslateAddinDialog( hWin, IDD_DLGMUI )

			' Add header
			AddHeaderToPage( hWin, _
				GetTranslateString( "4014", "User Interface" ), _
				GetTranslateString( "4015", "Choose the look and feel of your installer." ) _
				)

			' Add wizards to list box
			If WizardThemesNum Then
				For i As Integer = 0 To WizardThemesNum-1
					SendDlgItemMessage( hWin, IDC_LSTMUIWIZARD, LB_ADDSTRING, NULL, Cast( LPARAM, WizardThemes( i ).Name ) )
				Next
				SendDlgItemMessage( hWin, IDC_LSTMUIWIZARD, LB_SETCURSEL, Cast( WPARAM, WizardThemeDefault ), NULL )
			End If

			' Add headers to list box
			If HeaderThemesNum Then
				For i As Integer = 0 To HeaderThemesNum-1
					SendDlgItemMessage( hWin, IDC_LSTMUIHEADER, LB_ADDSTRING, NULL, Cast( LPARAM, HeaderThemes( i ).Name ) )
				Next
				SendDlgItemMessage( hWin, IDC_LSTMUIHEADER, LB_SETCURSEL, Cast( WPARAM, HeaderThemeDefault ), NULL )
			End If

			' Add icons to list box
			If IconThemesNum Then
				For i As Integer = 0 To IconThemesNum-1
					SendDlgItemMessage( hWin, IDC_LSTMUIICON, LB_ADDSTRING, NULL, Cast( LPARAM, IconThemes( i ).Name ) )
				Next
				SendDlgItemMessage( hWin, IDC_LSTMUIICON, LB_SETCURSEL, Cast( WPARAM, IconThemeDefault ), NULL )
			End If

			' Set defaults
			Dim CurWizardTheme As Integer = GetWizardThemeId( ProjectSettings.WizardInstall )
			Dim CurHeaderTheme As Integer = GetHeaderThemeId( ProjectSettings.HeaderInstall )
			Dim CurIconTheme As Integer = GetIconThemeId( ProjectSettings.IconInstall )
			If (	CurWizardTheme = -1 Or _
					CurHeaderTheme = -1 Or _
					CurIconTheme = -1 _
				) And _
				(	ProjectSettings.WizardInstall <> "" Or _
					ProjectSettings.WizardUninstall <> "" Or _
					ProjectSettings.HeaderInstall <> "" Or _
					ProjectSettings.HeaderInstallRight <> "" Or _
					ProjectSettings.HeaderUninstall <> "" Or _
					ProjectSettings.HeaderUninstallRight <> "" Or _
					ProjectSettings.IconInstall <> "" Or _
					ProjectSettings.IconUninstall <> "" _
				) Then
				CheckDlgButton( hWin, IDC_RBNMUICUSTOM, BST_CHECKED )
				EnableDlgItem( hWin, IDC_CHKMUINOWIZARD, FALSE )
				EnableDlgItem( hWin, IDC_LSTMUIICON, FALSE )
				EnableDlgItem( hWin, IDC_LSTMUIHEADER, FALSE )
				EnableDlgItem( hWin, IDC_LSTMUIWIZARD, FALSE )
				EnableDlgItem( hWin, IDC_BTNMUICUSTOM, TRUE )
			ElseIf CurWizardTheme <> -1 And _
				CurHeaderTheme <> -1 And _
				CurIconTheme <> -1 Then
				CheckDlgButton( hWin, IDC_RBNMUISTOCK, BST_CHECKED )
				EnableDlgItem( hWin, IDC_CHKMUINOWIZARD, TRUE )
				EnableDlgItem( hWin, IDC_LSTMUIICON, TRUE )
				EnableDlgItem( hWin, IDC_LSTMUIHEADER, TRUE )
				EnableDlgItem( hWin, IDC_BTNMUICUSTOM, FALSE )
				SendDlgItemMessage( hWin, IDC_LSTMUIWIZARD, LB_SETCURSEL, Cast( WPARAM, CurWizardTheme ), NULL )
				SendDlgItemMessage( hWin, IDC_LSTMUIHEADER, LB_SETCURSEL, Cast( WPARAM, CurHeaderTheme ), NULL )
				SendDlgItemMessage( hWin, IDC_LSTMUIICON, LB_SETCURSEL, Cast( WPARAM, CurIconTheme ), NULL )
				If (ProjectSettings.MuiOptions And PROJPUB_MUI_NOWELCOMEFINISHPAGE) <> NULL Then
					EnableDlgItem( hWin, IDC_LSTMUIWIZARD, FALSE )
					CheckDlgButton( hWin, IDC_CHKMUINOWIZARD, BST_CHECKED )
				Else
					EnableDlgItem( hWin, IDC_LSTMUIWIZARD, TRUE )
				End If
			Else
				CheckDlgButton( hWin, IDC_RBNMUIDEFAULTS, BST_CHECKED )
				EnableDlgItem( hWin, IDC_CHKMUINOWIZARD, FALSE )
				EnableDlgItem( hWin, IDC_LSTMUIICON, FALSE )
				EnableDlgItem( hWin, IDC_LSTMUIHEADER, FALSE )
				EnableDlgItem( hWin, IDC_LSTMUIWIZARD, FALSE )
				EnableDlgItem( hWin, IDC_BTNMUICUSTOM, FALSE )
			End If

			Return FALSE
			'
		Case WM_COMMAND
			Select Case HiWord( wParam )
				Case BN_CLICKED
					Select Case LoWord( wParam )
						Case IDC_RBNMUISTOCK
							If IsDlgButtonChecked( hWin, IDC_RBNMUISTOCK ) = BST_CHECKED Then
								EnableDlgItem( hWin, IDC_CHKMUINOWIZARD, TRUE )
								EnableDlgItem( hWin, IDC_LSTMUIICON, TRUE )
								EnableDlgItem( hWin, IDC_LSTMUIHEADER, TRUE )
								EnableDlgItem( hWin, IDC_BTNMUICUSTOM, FALSE )
								If IsDlgButtonChecked( hWin, IDC_CHKMUINOWIZARD ) = BST_CHECKED Then
									EnableDlgItem( hWin, IDC_LSTMUIWIZARD, FALSE )
								Else
									EnableDlgItem( hWin, IDC_LSTMUIWIZARD, TRUE )
								End If
							End If
							'
						Case IDC_RBNMUICUSTOM
							If IsDlgButtonChecked( hWin, IDC_RBNMUICUSTOM ) = BST_CHECKED Then
								EnableDlgItem( hWin, IDC_CHKMUINOWIZARD, FALSE )
								EnableDlgItem( hWin, IDC_LSTMUIICON, FALSE )
								EnableDlgItem( hWin, IDC_LSTMUIHEADER, FALSE )
								EnableDlgItem( hWin, IDC_LSTMUIWIZARD, FALSE )
								EnableDlgItem( hWin, IDC_BTNMUICUSTOM, TRUE )
							End If
							'
						Case IDC_RBNMUIDEFAULTS
							If IsDlgButtonChecked( hWin, IDC_RBNMUIDEFAULTS ) = BST_CHECKED Then
								EnableDlgItem( hWin, IDC_CHKMUINOWIZARD, FALSE )
								EnableDlgItem( hWin, IDC_LSTMUIICON, FALSE )
								EnableDlgItem( hWin, IDC_LSTMUIHEADER, FALSE )
								EnableDlgItem( hWin, IDC_LSTMUIWIZARD, FALSE )
								EnableDlgItem( hWin, IDC_BTNMUICUSTOM, FALSE )
							End If
							'
						Case IDC_CHKMUINOWIZARD
							If IsDlgButtonChecked( hWin, IDC_CHKMUINOWIZARD ) = BST_CHECKED Then
								EnableDlgItem( hWin, IDC_LSTMUIWIZARD, FALSE )
							Else
								EnableDlgItem( hWin, IDC_LSTMUIWIZARD, TRUE )
							End If
							'
						Case IDC_BTNMUICUSTOM
							DialogBox( hInstance, MAKEINTRESOURCE( IDD_DLGCUSTOMUI ), hWin, @CustomUIProjectDialogProc )
							'
					End Select
					'
			End Select
			'
		Case WM_CLOSE
			DestroyWindow( hWin )
			'
		Case WM_NOTIFY
			Select Case Cast( NMHDR Ptr, lParam )->code
				Case PSN_SETACTIVE
					PropSheet_SetWizButtons( Cast( NMHDR Ptr, lParam )->hwndFrom, PSWIZB_BACK Or PSWIZB_NEXT )
					'
				Case PSN_WIZNEXT
					If IsDlgButtonChecked( hWin, IDC_RBNMUISTOCK ) = BST_CHECKED Then
						'
						If IsDlgButtonChecked( hWin, IDC_CHKMUINOWIZARD ) = BST_CHECKED Then
							ProjectSettings.MuiOptions Or= PROJPUB_MUI_NOWELCOMEFINISHPAGE
						Else
							ProjectSettings.MuiOptions And= Not PROJPUB_MUI_NOWELCOMEFINISHPAGE
						End If
						Dim CurWizardTheme As Integer = SendDlgItemMessage( hWin, IDC_LSTMUIWIZARD, LB_GETCURSEL, NULL, NULL )
						If CurWizardTheme >= 0 Then
							ProjectSettings.WizardInstall = *WizardThemes( CurWizardTheme ).BitmapInstall
							ProjectSettings.WizardUninstall = *WizardThemes( CurWizardTheme ).BitmapUninstall
							If ProjectSettings.WizardUninstall = "" Then
								ProjectSettings.WizardUninstall = ProjectSettings.WizardInstall
							End If
							'
							buffer = GetWizardFilePath( ProjectSettings.WizardInstall )
							If buffer <> "" Then
								ProjectSettings.WizardInstall = buffer
							Else
								ErrorBox( hWin, GetTranslateString( "5005", "File not found:" ) & " " & ProjectSettings.WizardInstall )
								SetWindowLong( hWin, DWL_MSGRESULT, -1 )
								Return -1
							End If
							'
							buffer = GetWizardFilePath( ProjectSettings.WizardUninstall )
							If buffer <> "" Then
								ProjectSettings.WizardUninstall = buffer
							Else
								ErrorBox( hWin, GetTranslateString( "5005", "File not found:" ) & " " & ProjectSettings.WizardUninstall )
								SetWindowLong( hWin, DWL_MSGRESULT, -1 )
								Return -1
							End If
						Else
							ProjectSettings.WizardInstall = ""
							ProjectSettings.WizardUninstall = ""
						End If
						'
						Dim CurHeaderTheme As Integer = SendDlgItemMessage( hWin, IDC_LSTMUIHEADER, LB_GETCURSEL, NULL, NULL )
						If CurHeaderTheme >= 0 Then
							ProjectSettings.HeaderInstall = *HeaderThemes( CurHeaderTheme ).BitmapInstall
							ProjectSettings.HeaderInstallRight = *HeaderThemes( CurHeaderTheme ).BitmapInstallRight
							ProjectSettings.HeaderUninstall = *HeaderThemes( CurHeaderTheme ).BitmapUninstall
							ProjectSettings.HeaderUninstallRight = *HeaderThemes( CurHeaderTheme ).BitmapUninstallRight
							If ProjectSettings.HeaderInstallRight = "" Then
								ProjectSettings.HeaderInstallRight = ProjectSettings.HeaderInstall
							End If
							If ProjectSettings.HeaderUninstall = "" Then
								ProjectSettings.HeaderUninstall = ProjectSettings.HeaderInstall
							End If
							If ProjectSettings.HeaderUninstallRight = "" Then
								ProjectSettings.HeaderUninstallRight = ProjectSettings.HeaderInstallRight
							End If
							'
							buffer = GetHeaderFilePath( ProjectSettings.HeaderInstall )
							If buffer <> "" Then
								ProjectSettings.HeaderInstall = buffer
							Else
								ErrorBox( hWin, GetTranslateString( "5005", "File not found:" ) & " " & ProjectSettings.HeaderInstall )
								SetWindowLong( hWin, DWL_MSGRESULT, -1 )
								Return -1
							End If
							'
							buffer = GetHeaderFilePath( ProjectSettings.HeaderInstallRight )
							If buffer <> "" Then
								ProjectSettings.HeaderInstallRight = buffer
							Else
								ErrorBox( hWin, GetTranslateString( "5005", "File not found:" ) & " " & ProjectSettings.HeaderInstallRight )
								SetWindowLong( hWin, DWL_MSGRESULT, -1 )
								Return -1
							End If
							'
							buffer = GetHeaderFilePath( ProjectSettings.HeaderUninstall )
							If buffer <> "" Then
								ProjectSettings.HeaderUninstall = buffer
							Else
								ErrorBox( hWin, GetTranslateString( "5005", "File not found:" ) & " " & ProjectSettings.HeaderUninstall )
								SetWindowLong( hWin, DWL_MSGRESULT, -1 )
								Return -1
							End If
							'
							
							buffer = GetHeaderFilePath( ProjectSettings.HeaderUninstallRight )
							If buffer <> "" Then
								ProjectSettings.HeaderUninstallRight = buffer
							Else
								ErrorBox( hWin, GetTranslateString( "5005", "File not found:" ) & " " & ProjectSettings.HeaderUninstallRight )
								SetWindowLong( hWin, DWL_MSGRESULT, -1 )
								Return -1
							End If
						Else
							ProjectSettings.HeaderInstall = ""
							ProjectSettings.HeaderInstallRight = ""
							ProjectSettings.HeaderUninstall = ""
							ProjectSettings.HeaderUninstallRight = ""
						End If
						'
						Dim CurIconTheme As Integer = SendDlgItemMessage( hWin, IDC_LSTMUIICON, LB_GETCURSEL, NULL, NULL )
						If CurIconTheme >= 0 Then
							ProjectSettings.IconInstall = *IconThemes( CurIconTheme ).IconInstall
							ProjectSettings.IconUninstall = *IconThemes( CurIconTheme ).IconUninstall
							If ProjectSettings.IconUninstall = "" Then
								ProjectSettings.IconUninstall = ProjectSettings.IconInstall
							End If
							'
							buffer = GetIconFilePath( ProjectSettings.IconInstall )
							If buffer <> "" Then
								ProjectSettings.IconInstall = buffer
							Else
								ErrorBox( hWin, GetTranslateString( "5005", "File not found:" ) & " " & ProjectSettings.IconInstall )
								SetWindowLong( hWin, DWL_MSGRESULT, -1 )
								Return -1
							End If
							'
							buffer = GetIconFilePath( ProjectSettings.IconUninstall )
							If buffer <> "" Then
								ProjectSettings.IconUninstall = buffer
							Else
								ErrorBox( hWin, GetTranslateString( "5005", "File not found:" ) & " " & ProjectSettings.IconUninstall )
								SetWindowLong( hWin, DWL_MSGRESULT, -1 )
								Return -1
							End If
						Else
							ProjectSettings.IconInstall = ""
							ProjectSettings.IconUninstall = ""
						End If
						'
					ElseIf IsDlgButtonChecked( hWin, IDC_RBNMUICUSTOM ) = BST_CHECKED Then
						GetDlgItemText( hWin, IDC_EDTLICENSECUSTOM, @buffer, MAX_PATH )
						ProjectSettings.MuiOptions = 0
						'
					ElseIf IsDlgButtonChecked( hWin, IDC_RBNMUIDEFAULTS ) = BST_CHECKED Then
						ProjectSettings.MuiOptions = 0
						ProjectSettings.WizardInstall = ""
						ProjectSettings.WizardUninstall = ""
						ProjectSettings.HeaderInstall = ""
						ProjectSettings.HeaderInstallRight = ""
						ProjectSettings.HeaderUninstall = ""
						ProjectSettings.HeaderUninstallRight = ""
						ProjectSettings.IconInstall = ""
						ProjectSettings.IconUninstall = ""
						'
					End If
					'
			End Select
			'
		Case WM_HELP
			ShowContextHelp( Cast( HELPINFO Ptr, lParam ) )
			'
		Case Else
			Return FALSE
			'
	End Select

	Return TRUE

End Function


Sub LoadGraphics( _
	ByRef Location As Const String _
	)

	Dim wfd As WIN32_FIND_DATA
	Dim hwfd As HANDLE
	Dim CurFile As String

	' Find all files in path
	hwfd = FindFirstFile( Location & "\*.*", @wfd )
	If hwfd <> INVALID_HANDLE_VALUE Then
		Do
			If (wfd.dwFileAttributes And FILE_ATTRIBUTE_DIRECTORY) = NULL Then
				' A file is found, is it a *.grp file
				If LCase( Right( wfd.cFileName, 4 ) ) = ".grp" Then
					CurFile = Location & "\" & wfd.cFileName
					' Check Graphics type and add to list
					GetPrivateProfileString( "ProjPub", "FileType", "", @buffer, MAX_PATH, CurFile )
					Select Case buffer
						Case "Graphic-Wizard"
							AddToWizardThemes( CurFile )
							'
						Case "Graphic-Header"
							AddToHeaderThemes( CurFile )
							'
						Case "Graphic-Icon"
							AddToIconThemes( CurFile )
							'
					End Select
				End If
			Else
				' A new path is found
				If wfd.cFileName <> "." And wfd.cFileName <> ".." Then
					' Call myself to scan this path
					CurFile = Location & "\" & wfd.cFileName
					LoadGraphics( CurFile )
				End If
			End If
			If FindNextFile( hwfd, @wfd ) = FALSE Then
				' No more files in this path
				Exit Do
			End If
		Loop
		' Close the find handle
		FindClose( hwfd )
	End If

End Sub


Sub FreeGraphics( _
	)

	If WizardThemesNum Then
		For i As Integer = 0 To WizardThemesNum-1
			Delete[] WizardThemes( i ).Name
			Delete[] WizardThemes( i ).DescFile
			Delete[] WizardThemes( i ).BitmapInstall
			Delete[] WizardThemes( i ).BitmapUninstall
		Next
		WizardThemesNum = 0
	End If

	If HeaderThemesNum Then
		For i As Integer = 0 To HeaderThemesNum-1
			Delete[] HeaderThemes( i ).Name
			Delete[] HeaderThemes( i ).DescFile
			Delete[] HeaderThemes( i ).BitmapInstall
			Delete[] HeaderThemes( i ).BitmapInstallRight
			Delete[] HeaderThemes( i ).BitmapUninstall
			Delete[] HeaderThemes( i ).BitmapUninstallRight
		Next
		HeaderThemesNum = 0
	End If

	If IconThemesNum Then
		For i As Integer = 0 To IconThemesNum-1
			Delete[] IconThemes( i ).Name
			Delete[] IconThemes( i ).DescFile
			Delete[] IconThemes( i ).IconInstall
			Delete[] IconThemes( i ).IconUninstall
		Next
		IconThemesNum = 0
	End If

End Sub


Sub AddToWizardThemes( _
	ByVal Filename As String _
	)

	Dim size As Integer

	' Check if the array can accomodate the number of files available
	If WizardThemesNum >= WizardThemesMax Then

		'' There are more files than the array can provide
		WizardThemesMax += THEMES_INCREASE
		ReDim Preserve WizardThemes(WizardThemesMax - 1) As WizardTheme

	End If

	' Set filename of the current Wizard Themes
	WizardThemes( WizardThemesNum ).DescFile = New Byte[Len(Filename)+1]
	*WizardThemes( WizardThemesNum ).DescFile = Filename

	' Set Wizard Theme info
	size = GetPrivateProfileString( "Graphic-Wizard", "Name", "Unnamed", @buffer, MAX_PATH, Filename )
	WizardThemes( WizardThemesNum ).Name = New Byte[size+1]
	*WizardThemes( WizardThemesNum ).Name = buffer
	size = GetPrivateProfileString( "Graphic-Wizard", "Bitmap-Install", "", @buffer, MAX_PATH, Filename )
	WizardThemes( WizardThemesNum ).BitmapInstall = New Byte[size+1]
	*WizardThemes( WizardThemesNum ).BitmapInstall = buffer
	size = GetPrivateProfileString( "Graphic-Wizard", "Bitmap-Uninstall", "", @buffer, MAX_PATH, Filename )
	WizardThemes( WizardThemesNum ).BitmapUninstall = New Byte[size+1]
	*WizardThemes( WizardThemesNum ).BitmapUninstall = buffer

	' Check if default is requested
	If GetPrivateProfileInt( "ProjPub", "Default", 0, Filename ) Then
		WizardThemeDefault = WizardThemesNum
	End If

	' Increment Wizard Themes counter
	WizardThemesNum += 1

End Sub


Sub AddToHeaderThemes( _
	ByVal Filename As String _
	)

	Dim size As Integer

	' Check if the array can accomodate the number of files available
	If HeaderThemesNum >= HeaderThemesMax Then

		'' There are more files than the array can provide
		HeaderThemesMax += THEMES_INCREASE
		ReDim Preserve HeaderThemes(HeaderThemesMax - 1) As HeaderTheme

	End If

	' Set filename of the current Header Themes
	HeaderThemes( HeaderThemesNum ).DescFile = New Byte[Len(Filename)+1]
	*HeaderThemes( HeaderThemesNum ).DescFile = Filename

	' Set Header Theme info
	size = GetPrivateProfileString( "Graphic-Header", "Name", "Unnamed", @buffer, MAX_PATH, Filename )
	HeaderThemes( HeaderThemesNum ).Name = New Byte[size+1]
	*HeaderThemes( HeaderThemesNum ).Name = buffer
	size = GetPrivateProfileString( "Graphic-Header", "Bitmap-Install", "", @buffer, MAX_PATH, Filename )
	HeaderThemes( HeaderThemesNum ).BitmapInstall = New Byte[size+1]
	*HeaderThemes( HeaderThemesNum ).BitmapInstall = buffer
	size = GetPrivateProfileString( "Graphic-Header", "Bitmap-Install-Right", "", @buffer, MAX_PATH, Filename )
	HeaderThemes( HeaderThemesNum ).BitmapInstallRight = New Byte[size+1]
	*HeaderThemes( HeaderThemesNum ).BitmapInstallRight = buffer
	size = GetPrivateProfileString( "Graphic-Header", "Bitmap-Uninstall", "", @buffer, MAX_PATH, Filename )
	HeaderThemes( HeaderThemesNum ).BitmapUninstall = New Byte[size+1]
	*HeaderThemes( HeaderThemesNum ).BitmapUninstall = buffer
	size = GetPrivateProfileString( "Graphic-Header", "Bitmap-Uninstall-Right", "", @buffer, MAX_PATH, Filename )
	HeaderThemes( HeaderThemesNum ).BitmapUninstallRight = New Byte[size+1]
	*HeaderThemes( HeaderThemesNum ).BitmapUninstallRight = buffer

	' Check if default is requested
	If GetPrivateProfileInt( "ProjPub", "Default", 0, Filename ) Then
		HeaderThemeDefault = HeaderThemesNum
	End If

	' Increment Header Themes counter
	HeaderThemesNum += 1

End Sub


Sub AddToIconThemes( _
	ByVal Filename As String _
	)

	Dim size As Integer

	' Check if the array can accomodate the number of files available
	If IconThemesNum >= IconThemesMax Then

		'' There are more files than the array can provide
		IconThemesMax += THEMES_INCREASE
		ReDim Preserve IconThemes(IconThemesMax - 1) As IconTheme

	End If

	' Set filename of the current Icon Themes
	IconThemes( IconThemesNum ).DescFile = New Byte[Len(Filename)+1]
	*IconThemes( IconThemesNum ).DescFile = Filename

	' Set Icon Theme info
	size = GetPrivateProfileString( "Graphic-Icon", "Name", "Unnamed", @buffer, MAX_PATH, Filename )
	IconThemes( IconThemesNum ).Name = New Byte[size+1]
	*IconThemes( IconThemesNum ).Name = buffer
	size = GetPrivateProfileString( "Graphic-Icon", "Icon-Install", "", @buffer, MAX_PATH, Filename )
	IconThemes( IconThemesNum ).IconInstall = New Byte[size+1]
	*IconThemes( IconThemesNum ).IconInstall = buffer
	size = GetPrivateProfileString( "Graphic-Icon", "Icon-Uninstall", "", @buffer, MAX_PATH, Filename )
	IconThemes( IconThemesNum ).IconUninstall = New Byte[size+1]
	*IconThemes( IconThemesNum ).IconUninstall = buffer

	' Check if default is requested
	If GetPrivateProfileInt( "ProjPub", "Default", 0, Filename ) Then
		IconThemeDefault = IconThemesNum
	End If

	' Increment Icon Themes counter
	IconThemesNum += 1

End Sub


Function GetWizardThemeId( _
	ByRef filename As Const String _
	) As Integer

	If WizardThemesNum Then
		For i As Integer = 0 To WizardThemesNum-1
			If LCase( GetFileName( *WizardThemes(i).BitmapInstall ) ) = LCase( GetFileName( filename ) ) Then
				Return i
			End If
		Next
	End If

	Return -1

End Function


Function GetHeaderThemeId( _
	ByRef filename As Const String _
	) As Integer

	If HeaderThemesNum Then
		For i As Integer = 0 To HeaderThemesNum-1
			If LCase( GetFileName( *HeaderThemes(i).BitmapInstall ) ) = LCase( GetFileName( filename ) ) Then
				Return i
			End If
		Next
	End If

	Return -1

End Function


Function GetIconThemeId( _
	ByRef filename As Const String _
	) As Integer

	If IconThemesNum Then
		For i As Integer = 0 To IconThemesNum-1
			If LCase( GetFileName( *IconThemes(i).IconInstall ) ) = LCase( GetFileName( filename ) ) Then
				Return i
			End If
		Next
	End If

	Return -1

End Function


Function GetWizardFilePath( _
	ByRef filename As Const String _
	) As String

	If FileExists( IDEPath + CustomProjPubGraphicsPath + filename ) Then
		Return GetRelativePath( IDEPath + CustomProjPubGraphicsPath + filename, CurProjectPath )
	ElseIf FileExists( IDEPath + ProjPubGraphicsPath + "Wizard\" + filename ) Then
		Return GetRelativePath( IDEPath + ProjPubGraphicsPath + "Wizard\" + filename, CurProjectPath )
	ElseIf FileExists( GetDir( GlobalSettings.NSISPath ) + NSISGraphicsPath +"Wizard\" + filename ) Then
		Return "${NSISDIR}" + NSISGraphicsPath + "Wizard\" + filename
	Else
		Return ""
	End If

End Function


Function GetHeaderFilePath( _
	ByRef filename As Const String _
	) As String

	If FileExists( IDEPath + CustomProjPubGraphicsPath + filename ) Then
		Return GetRelativePath( IDEPath + CustomProjPubGraphicsPath + filename, CurProjectPath )
	ElseIf FileExists( IDEPath + ProjPubGraphicsPath + "Header\" + filename ) Then
		Return GetRelativePath( IDEPath + ProjPubGraphicsPath + "Header\" + filename, CurProjectPath )
	ElseIf FileExists( GetDir( GlobalSettings.NSISPath ) + NSISGraphicsPath +"Header\" + filename ) Then
		Return "${NSISDIR}" + NSISGraphicsPath + "Header\" + filename
	Else
		Return ""
	End If

End Function


Function GetIconFilePath( _
	ByRef filename As Const String _
	) As String

	If FileExists( IDEPath + CustomProjPubGraphicsPath + filename ) Then
		Return GetRelativePath( IDEPath + CustomProjPubGraphicsPath + filename, CurProjectPath )
	ElseIf FileExists( IDEPath + ProjPubGraphicsPath + "Icons\" + filename ) Then
		Return GetRelativePath( IDEPath + ProjPubGraphicsPath + "Icons\" + filename, CurProjectPath )
	ElseIf FileExists( GetDir( GlobalSettings.NSISPath ) + NSISGraphicsPath +"Icons\" + filename ) Then
		Return "${NSISDIR}" + NSISGraphicsPath + "Icons\" + filename
	Else
		Return ""
	End If

End Function

