;Project Publisher
;NSIS Installer Script
;Written with FbEdit Project Publisher

;--------------------------------
;Set data compressor

	SetCompressor /SOLID lzma

;--------------------------------
;Defines

	!define PRODUCT_NAME						"Project Publisher"
	!define PRODUCT_FILE						"ProjPub"
	!define PRODUCT_LICENSE						"copying.txt"
	!define PRODUCT_ICON						"Res\ProjPub.ico"
	!define PRODUCT_UNICON						"Res\ProjPub.ico"
	!define PRODUCT_HEADERIMAGE_BITMAP			"Res\Header.bmp"
	!define PRODUCT_HEADERIMAGE_UNBITMAP		"Res\Header.bmp"
	!define PRODUCT_WELCOMEFINISHPAGE_BITMAP	"Res\Banner.bmp"
	!define PRODUCT_UNWELCOMEFINISHPAGE_BITMAP	"Res\Banner.bmp"
	!define PRODUCT_REGISTRY_KEY				"ProjPub"
	!define PRODUCT_INSTALL_DIR					"FbEdit"
	!define PRODUCT_AUTHOR						"Arnel A. Borja"
	!define PRODUCT_WEB_SITE					"http://wargaleon.users.sourceforge.net"
	!define PRODUCT_DISPLAY_VERSION				"0.4"
	!define PRODUCT_VERSION_MAJOR				"0"
	!define PRODUCT_VERSION_MINOR				"4"
	!define PRODUCT_VERSION_BUILD				"0"
	!define PRODUCT_VERSION_REVISION			"0"
	!define PRODUCT_VERSION						"${PRODUCT_VERSION_MAJOR}.${PRODUCT_VERSION_MINOR}.${PRODUCT_VERSION_BUILD}.${PRODUCT_VERSION_REVISION}"

;--------------------------------
;Include nsDialogs

	!include LogicLib.nsh
	!include WinMessages.nsh
	!include FileFunc.nsh

;--------------------------------
;Include Modern UI

	!include MUI2.nsh

;--------------------------------
;Include Multi-User

	;Default installation folder
	!define MULTIUSER_INSTALLMODE_INSTDIR "${PRODUCT_INSTALL_DIR}"

	;Get installation folder from registry if available
	!define MULTIUSER_INSTALLMODE_DEFAULT_REGISTRY_KEY "Software\${PRODUCT_REGISTRY_KEY}"
	!define MULTIUSER_INSTALLMODE_DEFAULT_REGISTRY_VALUENAME "InstallDir"
	!define MULTIUSER_INSTALLMODE_INSTDIR_REGISTRY_KEY "Software\${PRODUCT_REGISTRY_KEY}"
	!define MULTIUSER_INSTALLMODE_INSTDIR_REGISTRY_VALUENAME "InstallDir"

	!define MULTIUSER_EXECUTIONLEVEL Highest
	!define MULTIUSER_MUI
	!define MULTIUSER_INSTALLMODE_COMMANDLINE
	!include MultiUser.nsh

;--------------------------------
;General

	;Name and file
	Name "${PRODUCT_NAME} ${PRODUCT_VERSION}"
	OutFile "${PRODUCT_FILE}-${PRODUCT_VERSION}.exe"

;--------------------------------
;Interface Configuration

	!define MUI_ICON "${PRODUCT_ICON}"
	!define MUI_UNICON "${PRODUCT_UNICON}"
	!define MUI_HEADERIMAGE
	!define MUI_HEADERIMAGE_BITMAP "${PRODUCT_HEADERIMAGE_BITMAP}"
	!define MUI_HEADERIMAGE_UNBITMAP "${PRODUCT_HEADERIMAGE_UNBITMAP}"
	!define MUI_WELCOMEFINISHPAGE_BITMAP "${PRODUCT_WELCOMEFINISHPAGE_BITMAP}"
	!define MUI_UNWELCOMEFINISHPAGE_BITMAP "${PRODUCT_UNWELCOMEFINISHPAGE_BITMAP}"
	!define MUI_ABORTWARNING

;--------------------------------
;Language Selection Dialog Settings

	;Remember the installer language
	!define MUI_LANGDLL_REGISTRY_ROOT "SHCTX"
	!define MUI_LANGDLL_REGISTRY_KEY "Software\${PRODUCT_REGISTRY_KEY}"
	!define MUI_LANGDLL_REGISTRY_VALUENAME "InstallLang"

;--------------------------------
;Pages

	!define MUI_WELCOMEPAGE_TITLE_3LINES
	!insertmacro MUI_PAGE_WELCOME
	!insertmacro MUI_PAGE_LICENSE "${PRODUCT_LICENSE}"
	!insertmacro MULTIUSER_PAGE_INSTALLMODE
	!insertmacro MUI_PAGE_COMPONENTS
	!insertmacro MUI_PAGE_DIRECTORY

	;Finish Page Configuration
	!define MUI_FINISHPAGE_SHOWREADME "$INSTDIR\Addins\Help\ProjPub.chm"
	!define MUI_FINISHPAGE_SHOWREADME_TEXT "Show ${PRODUCT_NAME} Manual"
	!define MUI_FINISHPAGE_LINK "Go to ${PRODUCT_NAME} website"
	!define MUI_FINISHPAGE_LINK_LOCATION "http://wargaleon.users.sourceforge.net"

	!define MUI_PAGE_CUSTOMFUNCTION_PRE PreStartMenu
	!insertmacro MUI_PAGE_INSTFILES
	!insertmacro MUI_PAGE_FINISH

	!define MUI_WELCOMEPAGE_TITLE_3LINES
	!insertmacro MUI_UNPAGE_WELCOME
	!insertmacro MUI_UNPAGE_CONFIRM
	!insertmacro MUI_UNPAGE_INSTFILES
	!insertmacro MUI_UNPAGE_FINISH

;--------------------------------
;Languages

	;Insert each language here with !insertmacro MUI_LANGUAGE "[LANGUAGE]"

	!insertmacro MUI_LANGUAGE "English"

;--------------------------------
;Reserve Files

	;If you are using solid compression, files that are required before
	;the actual installation should be stored first in the data block,
	;because this will make your installer start faster.

	!insertmacro MUI_RESERVEFILE_LANGDLL

;--------------------------------
;Installer Metadata

	VIAddVersionKey "ProductName"		"${PRODUCT_NAME}"
	VIAddVersionKey "Comments"		"${PRODUCT_NAME} ${PRODUCT_VERSION} Installer"
	VIAddVersionKey "CompanyName"		"${PRODUCT_AUTHOR}"
	VIAddVersionKey "LegalCopyright"	" ${PRODUCT_AUTHOR}"
	VIAddVersionKey "FileDescription"	"${PRODUCT_NAME}"
	VIAddVersionKey "FileVersion"		"${PRODUCT_VERSION}"
	VIProductVersion "${PRODUCT_VERSION}"

;--------------------------------
;Installer Sections

Section

	SetOutPath "$INSTDIR\Addins"

	File "ProjPub.dll"

	SetOutPath "$INSTDIR\Addins\Help"

	File "Help\ProjPub.chm"

	SetOutPath "$INSTDIR\ProjPub\Graphics\Checks"

	File "Graphics\Checks\big.grp"
	File "Graphics\Checks\classic.grp"
	File "Graphics\Checks\classic-cross.grp"
	File "Graphics\Checks\colorful.grp"
	File "Graphics\Checks\grey.grp"
	File "Graphics\Checks\grey-cross.grp"
	File "Graphics\Checks\modern.grp"
	File "Graphics\Checks\red.grp"
	File "Graphics\Checks\red-round.grp"
	File "Graphics\Checks\simple.grp"
	File "Graphics\Checks\simple-round2.grp"
	File "Graphics\Checks\simple-round.grp"

	SetOutPath "$INSTDIR\ProjPub\Graphics\Header"

	File "Graphics\Header\fbasic.bmp"
	File "Graphics\Header\fbasic.grp"
	File "Graphics\Header\fbedit.bmp"
	File "Graphics\Header\fbedit.grp"
	File "Graphics\Header\nsis.grp"
	File "Graphics\Header\orange.grp"
	File "Graphics\Header\orange-nsis.grp"
	File "Graphics\Header\win.grp"

	SetOutPath "$INSTDIR\ProjPub\Graphics\Icons"

	File "Graphics\Icons\arrow.grp"
	File "Graphics\Icons\arrow2.grp"
	File "Graphics\Icons\box.grp"
	File "Graphics\Icons\classic.grp"
	File "Graphics\Icons\fbasic.grp"
	File "Graphics\Icons\fbasic.ico"
	File "Graphics\Icons\fbedit.grp"
	File "Graphics\Icons\fbedit.ico"
	File "Graphics\Icons\llama-blue.grp"
	File "Graphics\Icons\llama-grey.grp"
	File "Graphics\Icons\modern.grp"
	File "Graphics\Icons\modern-blue.grp"
	File "Graphics\Icons\modern-blue-full.grp"
	File "Graphics\Icons\modern-colorful.grp"
	File "Graphics\Icons\modern-full.grp"
	File "Graphics\Icons\nsis1.grp"
	File "Graphics\Icons\orange.grp"
	File "Graphics\Icons\orange-nsis.grp"
	File "Graphics\Icons\pixel.grp"
	File "Graphics\Icons\win.grp"

	SetOutPath "$INSTDIR\ProjPub\Graphics\Wizard"

	File "Graphics\Wizard\arrow.grp"
	File "Graphics\Wizard\fbasic.bmp"
	File "Graphics\Wizard\fbasic.grp"
	File "Graphics\Wizard\fbedit.bmp"
	File "Graphics\Wizard\fbedit.grp"
	File "Graphics\Wizard\llama.grp"
	File "Graphics\Wizard\nsis.grp"
	File "Graphics\Wizard\nullsoft.grp"
	File "Graphics\Wizard\orange.grp"
	File "Graphics\Wizard\orange-nsis.grp"
	File "Graphics\Wizard\win.grp"

	SetOutPath "$INSTDIR\ProjPub\Languages"

	File "Languages\German.lng"

	SetOutPath "$INSTDIR\ProjPub\Licenses"

	File "Licenses\apache2.lic"
	File "Licenses\apache2.txt"
	File "Licenses\bsd.lic"
	File "Licenses\bsd.txt"
	File "Licenses\freeware.lic"
	File "Licenses\freeware.txt"
	File "Licenses\gpl2.lic"
	File "Licenses\gpl2.txt"
	File "Licenses\gpl3.lic"
	File "Licenses\gpl3.txt"
	File "Licenses\lgpl2.1.lic"
	File "Licenses\lgpl2.1.txt"
	File "Licenses\lgpl2.lic"
	File "Licenses\lgpl2.txt"
	File "Licenses\zlib.lic"
	File "Licenses\zlib.txt"

	;Create uninstaller
	WriteUninstaller "$INSTDIR\ProjPub\uninstall.exe"

	Call InstallNonRemDriveItems

SectionEnd

Section /o "$(NAME_SecRemDriveInstall)" SecRemDriveInstall

SectionEnd

;--------------------------------
;Descriptions

	;Language strings
	LangString NAME_SecRemDriveInstall			${LANG_ENGLISH}		"Install In Removable Drive"
	LangString DESC_SecRemDriveInstall			${LANG_ENGLISH}		"This will disallow installation of registry entries and Start Menu items for installing in removable drives."

	;Assign language strings to sections
	!insertmacro MUI_FUNCTION_DESCRIPTION_BEGIN
	!insertmacro MUI_DESCRIPTION_TEXT ${SecRemDriveInstall}			$(DESC_SecRemDriveInstall)
	!insertmacro MUI_FUNCTION_DESCRIPTION_END

;--------------------------------
;Uninstaller Section

Section "Uninstall"

	Delete "$INSTDIR\ProjPub\uninstall.exe"
	Delete "$INSTDIR\Addins\ProjPub.dll"
	Delete "$INSTDIR\Addins\Help\ProjPub.chm"
	Delete "$INSTDIR\ProjPub\Graphics\Checks\big.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Checks\classic.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Checks\classic-cross.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Checks\colorful.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Checks\grey.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Checks\grey-cross.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Checks\modern.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Checks\red.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Checks\red-round.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Checks\simple.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Checks\simple-round2.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Checks\simple-round.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Header\fbasic.bmp"
	Delete "$INSTDIR\ProjPub\Graphics\Header\fbasic.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Header\fbedit.bmp"
	Delete "$INSTDIR\ProjPub\Graphics\Header\fbedit.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Header\nsis.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Header\orange.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Header\orange-nsis.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Header\win.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\arrow.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\arrow2.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\box.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\classic.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\fbasic.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\fbasic.ico"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\fbedit.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\fbedit.ico"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\llama-blue.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\llama-grey.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\modern.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\modern-blue.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\modern-blue-full.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\modern-colorful.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\modern-full.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\nsis1.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\orange.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\orange-nsis.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\pixel.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Icons\win.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Wizard\arrow.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Wizard\fbasic.bmp"
	Delete "$INSTDIR\ProjPub\Graphics\Wizard\fbasic.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Wizard\fbedit.bmp"
	Delete "$INSTDIR\ProjPub\Graphics\Wizard\fbedit.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Wizard\llama.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Wizard\nsis.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Wizard\nullsoft.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Wizard\orange.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Wizard\orange-nsis.grp"
	Delete "$INSTDIR\ProjPub\Graphics\Wizard\win.grp"
	Delete "$INSTDIR\ProjPub\Languages\German.lng"
	Delete "$INSTDIR\ProjPub\Licenses\apache2.lic"
	Delete "$INSTDIR\ProjPub\Licenses\apache2.txt"
	Delete "$INSTDIR\ProjPub\Licenses\bsd.lic"
	Delete "$INSTDIR\ProjPub\Licenses\bsd.txt"
	Delete "$INSTDIR\ProjPub\Licenses\freeware.lic"
	Delete "$INSTDIR\ProjPub\Licenses\freeware.txt"
	Delete "$INSTDIR\ProjPub\Licenses\gpl2.lic"
	Delete "$INSTDIR\ProjPub\Licenses\gpl2.txt"
	Delete "$INSTDIR\ProjPub\Licenses\gpl3.lic"
	Delete "$INSTDIR\ProjPub\Licenses\gpl3.txt"
	Delete "$INSTDIR\ProjPub\Licenses\lgpl2.1.lic"
	Delete "$INSTDIR\ProjPub\Licenses\lgpl2.1.txt"
	Delete "$INSTDIR\ProjPub\Licenses\lgpl2.lic"
	Delete "$INSTDIR\ProjPub\Licenses\lgpl2.txt"
	Delete "$INSTDIR\ProjPub\Licenses\zlib.lic"
	Delete "$INSTDIR\ProjPub\Licenses\zlib.txt"

	RMDir "$INSTDIR\ProjPub\Licenses"
	RMDir "$INSTDIR\ProjPub\Languages"
	RMDir "$INSTDIR\ProjPub\Graphics\Wizard"
	RMDir "$INSTDIR\ProjPub\Graphics\Icons"
	RMDir "$INSTDIR\ProjPub\Graphics\Header"
	RMDir "$INSTDIR\ProjPub\Graphics\Checks"
	RMDir "$INSTDIR\ProjPub\Graphics"
	RMDir "$INSTDIR\ProjPub"
	RMDir "$INSTDIR\Addins\Help"
	RMDir "$INSTDIR\Addins"
	RMDir "$INSTDIR"

	ReadRegStr $0 SHCTX "Software\${PRODUCT_REGISTRY_KEY}" "InstallDir"

	${If} $0 == $INSTDIR
		DeleteRegKey /ifempty SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}"
		DeleteRegKey /ifempty SHCTX "Software\${PRODUCT_REGISTRY_KEY}"
	${EndIf}

SectionEnd

;--------------------------------
;This will skip installing Start Menu items if installing
;into removable drives

Function PreStartMenu

	${If} ${SectionIsSelected} ${SecRemDriveInstall}
		Abort
	${EndIf}

FunctionEnd

;--------------------------------
;This will install the registry entries and start menu
;items if not installing into removable drives

Function InstallNonRemDriveItems

	${IfNot} ${SectionIsSelected} ${SecRemDriveInstall}

		;Store installation folder
		WriteRegStr SHCTX "Software\${PRODUCT_REGISTRY_KEY}" "InstallDir" "$INSTDIR"

		WriteRegStr SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "DisplayName" "${PRODUCT_NAME}"
		WriteRegStr SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "DisplayVersion" "${PRODUCT_DISPLAY_VERSION}"
		WriteRegStr SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "UninstallString" "$\"$INSTDIR\ProjPub\uninstall.exe$\""
		WriteRegStr SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "InstallLocation" "$\"$INSTDIR$\""
		WriteRegStr SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "DisplayIcon" "$\"$INSTDIR\ProjPub\uninstall.exe$\""
		WriteRegStr SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "Publisher" "${PRODUCT_AUTHOR}"
;		WriteRegStr SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "InstallSource" ""
		WriteRegStr SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "URLInfoAbout" "${PRODUCT_WEB_SITE}"
		WriteRegStr SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "DisplayVersion" "${PRODUCT_VERSION}"
		WriteRegDWORD SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "VersionMajor" ${PRODUCT_VERSION_MAJOR}
		WriteRegDWORD SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "VersionMinor" ${PRODUCT_VERSION_MINOR}
		WriteRegDWORD SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "NoModify (DWORD)" 0x1
		WriteRegDWORD SHCTX "Software\Microsoft\Windows\CurrentVersion\Uninstall\${PRODUCT_REGISTRY_KEY}" "NoRepair (DWORD)" 0x1

	${EndIf}

FunctionEnd

;--------------------------------
;Installer Functions

Function .onInit

	!insertmacro MULTIUSER_INIT

	!insertmacro MUI_LANGDLL_DISPLAY

FunctionEnd

Function .onVerifyInstDir

	; if $INSTDIR don't have FbEdit.exe, don't let us install there
	${IfNot} ${FileExists} "$INSTDIR\FbEdit.exe"
		Abort
	${EndIf}

FunctionEnd

;--------------------------------
;Uninstaller Functions

Function un.onInit

	!insertmacro MULTIUSER_UNINIT

	!insertmacro MUI_UNGETLANGUAGE

FunctionEnd

